html {
  font-size: 16px;
}

body {
  max-width: 1024px;
  margin: 0 auto;
  font-family: sans-serif;
}

h1 { font-size: 3rem; }
h2 { font-size: 2.5rem; }
h3 { font-size: 1.5rem; }

.section {
  padding-left: 1rem;
  border: 1px solid black;
  border-radius: 5px;
  margin: 5px 0;
}
